# Tiky
A TikTok Autoclaimer & Turbo.
Automatically and periodically tries to claim multiple TikTok usernames using private API.

### Install
- Download latest [Python](https://www.python.org/downloads/) (Make sure you check the 'Enviroment Variable' box during setup)
- Install Tiky from Command Line using PyPi, with this command: <br> `pip3 install tiky`
- You're done! Just type `tiky` in Command Line to run it.

### Options
Run `tiky -h` to show all options.<br>
A cool feature is the Turbo mode, you can activate it with `tiky -t`.
![Screenshot](https://i.imgur.com/E4TrERk.png)

### API Documentation
Tiky is using a private unofficial TikTok API.
https://documenter.getpostman.com/view/10262162/T17FC9Ms?version=latest

![Screenshot](https://i.imgur.com/JoCRZBW.png)

Contact me on Discord (<b>dexy#7742</b>) to purchase an API KEY.